@@ -124,29 +124,27 @@ comb_EIG4 <- function(x, ntop_pred = NULL, criterion = "RMSE") {
         call. = FALSE)
 
     if (is.null(x$Forecasts_Test) & is.null(x$Actual_Test)) {
-        result <- structure(list(Method = "Trimmed Bias-Corrected Eigenvector Approach", Models = modelnames, Intercept = as.numeric(intercept), Weights = weights,
-            Top_Predictors = ntop_pred, Ranking = unname(ranking), Fitted = fitted, Accuracy_Train = accuracy_insample, Input_Data = list(Actual_Train = x$Actual_Train,
-                Forecasts_Train = x$Forecasts_Train), Predict = predict.comb_EIG4), class = c("foreccomb_res"))
-        rownames(result$Accuracy_Train) <- "Training Set"
+      result <- foreccomb_res(method = "Trimmed Bias-Corrected Eigenvector Approach", modelnames = modelnames, intercept = as.numeric(intercept), weights = weights,
+                              top_predictors = ntop_pred, ranking = unname(ranking), fitted = fitted, accuracy_insample = accuracy_insample,
+                              input_data = list(Actual_Train = x$Actual_Train, Forecasts_Train = x$Forecasts_Train),
+                              predict = predict.comb_EIG4)
     }
 
     if (is.null(x$Forecasts_Test) == FALSE) {
         newpred_matrix <- x$Forecasts_Test
         pred <- as.vector(as.vector(intercept) + newpred_matrix %*% weights)
         if (is.null(x$Actual_Test) == TRUE) {
-            result <- structure(list(Method = "Trimmed Bias-Corrected Eigenvector Approach", Models = modelnames, Intercept = as.numeric(intercept), Weights = weights,
-                Top_Predictors = ntop_pred, Ranking = unname(ranking), Fitted = fitted, Accuracy_Train = accuracy_insample, Forecasts_Test = pred, Input_Data = list(Actual_Train = x$Actual_Train,
-                  Forecasts_Train = x$Forecasts_Train, Forecasts_Test = x$Forecasts_Test), Predict = predict.comb_EIG4), class = c("foreccomb_res"))
-            rownames(result$Accuracy_Train) <- "Training Set"
+          result <- foreccomb_res(method = "Trimmed Bias-Corrected Eigenvector Approach", modelnames = modelnames, intercept = as.numeric(intercept), weights = weights,
+                                  top_predictors = ntop_pred, ranking = unname(ranking), fitted = fitted, accuracy_insample = accuracy_insample, pred = pred,
+                                  input_data = list(Actual_Train = x$Actual_Train, Forecasts_Train = x$Forecasts_Train, Forecasts_Test = x$Forecasts_Test),
+                                  predict = predict.comb_EIG4)
         } else {
             newobs_vector <- x$Actual_Test
             accuracy_outsample <- accuracy(pred, newobs_vector)
-            result <- structure(list(Method = "Trimmed Bias-Corrected Eigenvector Approach", Models = modelnames, Intercept = as.numeric(intercept), Weights = weights,
-                Top_Predictors = ntop_pred, Ranking = unname(ranking), Fitted = fitted, Accuracy_Train = accuracy_insample, Forecasts_Test = pred, Accuracy_Test = accuracy_outsample,
-                Input_Data = list(Actual_Train = x$Actual_Train, Forecasts_Train = x$Forecasts_Train, Actual_Test = x$Actual_Test, Forecasts_Test = x$Forecasts_Test),
-                Predict = predict.comb_EIG4), class = c("foreccomb_res"))
-            rownames(result$Accuracy_Train) <- "Training Set"
-            rownames(result$Accuracy_Test) <- "Test Set"
+            result <- foreccomb_res(method = "Trimmed Bias-Corrected Eigenvector Approach", modelnames = modelnames, intercept = as.numeric(intercept), weights = weights,
+                top_predictors = ntop_pred, ranking = unname(ranking), fitted = fitted, accuracy_insample = accuracy_insample, pred = pred, accuracy_outsample = accuracy_outsample,
+                input_data = list(Actual_Train = x$Actual_Train, Forecasts_Train = x$Forecasts_Train, Actual_Test = x$Actual_Test, Forecasts_Test = x$Forecasts_Test),
+                predict = predict.comb_EIG4)
         }
     }
     return(result)
